#include "univ.i"
#line 2 "lexyy.cc"

#line 4 "lexyy.cc"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif





#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
static int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

static void yyrestart ( FILE *input_file  );
MY_ATTRIBUTE((unused)) static void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
static YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
static void yy_delete_buffer ( YY_BUFFER_STATE b  );
static void yy_flush_buffer ( YY_BUFFER_STATE b  );
MY_ATTRIBUTE((unused)) static void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
MY_ATTRIBUTE((unused)) static void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

static void *yyalloc ( yy_size_t  );
static void *yyrealloc ( void *, yy_size_t  );
static void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

static FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;


static int yylineno = 1;


#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 102
#define YY_END_OF_BUFFER 103
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[307] =
    {   0,
        0,    0,   97,   97,    0,    0,    0,    0,  103,  101,
      100,  100,    8,  101,   92,    5,   81,   87,   90,   88,
       85,   89,  101,   91,    1,  101,   86,   84,   82,   83,
       95,   74,   74,   74,   74,   74,   74,   74,   74,   74,
       74,   74,   74,   74,   74,   74,   74,   74,   74,   74,
       93,   94,   97,   98,    6,    7,    9,   10,  100,    4,
       76,   96,    2,    1,    3,   77,   78,   80,   79,    0,
       74,    0,   74,   74,   74,   74,   36,   74,   74,   74,
       74,   74,   74,   74,   74,   74,   74,   74,   74,   74,
       23,   17,   20,   74,   74,   74,   74,   74,   74,   46,

       52,   74,   14,   74,   74,   74,   74,   74,   74,   74,
       74,   74,   74,   74,   74,   74,   74,   74,   97,   98,
       98,   99,    6,    7,    9,   10,    2,    0,   75,   13,
       37,   74,   74,   74,   74,   74,   74,   74,   74,   74,
       74,   74,   74,   74,   74,   22,   74,   74,   34,   74,
       74,   74,   74,   18,   74,   74,   74,   74,   74,   15,
       74,   74,   74,   74,   74,   74,   74,   43,   74,   12,
       74,   74,   74,   74,   74,   74,   74,   74,   74,   74,
        0,   75,   74,   74,   19,   74,   74,   74,   74,   74,
       74,   74,   74,   74,   74,   38,   25,   74,   67,   74,

       32,   74,   74,   74,   74,   40,   74,   72,   69,   27,
       71,   74,   11,   55,   74,   74,   74,   74,   74,   74,
       74,   74,   24,   74,   74,   74,   74,   74,   74,   66,
        0,   21,   74,   57,   74,   74,   74,   31,   74,   74,
       74,   74,   74,   26,   56,   74,   49,   74,   62,   74,
       74,   35,   74,   74,   74,   74,   70,   74,   48,   74,
       74,   74,   74,   33,   28,    0,   73,   74,   64,   61,
       47,   74,   54,   74,   44,   74,   39,   63,   74,   74,
       29,   74,   30,   60,   74,   50,   42,   41,   74,   45,
       53,   74,   74,   74,   74,   74,   74,   68,   58,   74,

       65,   74,   51,   16,   59,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    6,    7,    1,    8,    9,
       10,   11,   12,   13,   14,   15,   16,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   18,   19,   20,
       21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
       31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
       41,   42,   43,   44,   45,   46,   47,   48,   49,   34,
        1,    1,    1,    1,   50,    1,   34,   34,   34,   34,

       34,   34,   34,   34,   34,   34,   34,   51,   34,   34,
       34,   34,   52,   34,   53,   34,   34,   34,   34,   34,
       34,   34,   54,    1,   55,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[56] =
    {   0,
        1,    1,    1,    2,    3,    1,    1,    4,    1,    1,
        5,    1,    1,    1,    1,    6,    7,    1,    1,    1,
        8,    1,    1,    6,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    1,    1
    } ;

static const flex_int16_t yy_base[320] =
    {   0,
        0,    0,  262,  259,  249,  244,  239,  234,  236,  960,
       54,   56,  960,    0,  960,  960,  960,  960,  960,  960,
      960,  960,  217,  220,   45,  186,  960,   42,  960,  184,
      960,   45,   49,   55,   51,   65,   80,   50,   69,   94,
       90,   92,  104,   60,  114,  116,  131,  134,  135,  149,
      960,  960,    0,   61,    0,  194,    0,  197,  133,    0,
      960,  960,  163,   53,  143,  960,  960,  960,  960,  147,
      125,  123,  138,  151,  152,  153,  155,  166,  169,  173,
      170,  171,  176,  180,  193,  182,  200,  204,  206,  209,
      210,  211,  213,  224,  225,  226,  235,  240,  242,  245,

      251,  252,  255,  256,  258,  261,  270,  274,  272,  277,
      289,  288,  276,  294,  295,  300,  304,  305,    0,   79,
      110,  960,    0,  116,    0,  113,   98,   58,    0,  306,
      315,  316,  318,  319,  322,  328,  329,  332,  334,  338,
      344,  353,  351,  354,  366,  360,  367,  369,  376,  378,
      381,  385,  388,  382,  394,  400,  403,  404,  406,  407,
      410,  417,  423,  424,  426,  429,  433,  440,  442,  443,
      444,  445,  454,  456,  459,  461,  472,  473,  474,  477,
       53,    0,  475,  478,  479,  490,  502,  504,  505,  507,
      508,  509,  511,  518,  520,  523,  524,  525,  529,  538,

      541,  542,  543,  545,  547,  544,  556,  557,  558,  559,
      560,  569,  572,  574,  578,  581,  579,  583,  588,  590,
      600,  601,  602,  607,  611,  613,  612,  618,  622,  629,
       41,  634,  636,  638,  639,  643,  645,  648,  649,  650,
      655,  659,  661,  660,  670,  675,  676,  679,  680,  682,
      686,  689,  691,  696,  693,  700,  705,  706,  709,  711,
      712,  716,  722,  723,  726,   72,  727,  736,  737,  738,
      739,  740,  742,  743,  752,  753,  755,  757,  758,  759,
      764,  770,  769,  771,  774,  784,  785,  786,  787,  789,
      790,  791,  796,  801,  802,  803,  806,  807,  812,  817,

      816,  823,  826,  828,  832,  960,  872,  881,  890,  893,
      896,  900,  909,  918,  927,  936,  943,  947,  950
    } ;

static const flex_int16_t yy_def[320] =
    {   0,
      306,    1,  307,  307,  308,  308,  309,  309,  306,  306,
      306,  306,  306,  310,  306,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  311,  306,  306,  306,  306,
      306,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      306,  306,  313,  314,  315,  306,  316,  306,  306,  310,
      306,  306,  306,  306,  311,  306,  306,  306,  306,  317,
      312,  318,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,

      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  313,  314,
      314,  306,  315,  306,  316,  306,  306,  306,  319,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      306,  319,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,

      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      306,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  306,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,
      312,  312,  312,  312,  312,  312,  312,  312,  312,  312,

      312,  312,  312,  312,  312,    0,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  306,  306
    } ;

static const flex_int16_t yy_nxt[1016] =
    {   0,
       10,   11,   12,   13,   10,   14,   15,   16,   17,   18,
       19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
       29,   30,   31,   10,   32,   33,   34,   35,   36,   37,
       38,   38,   39,   38,   38,   40,   41,   42,   43,   44,
       38,   45,   46,   47,   48,   49,   50,   38,   38,   38,
       38,   38,   38,   51,   52,   59,   59,   59,   59,   63,
       70,   64,   67,   68,   70,   70,   70,   63,   72,   64,
       70,  121,   72,   72,   72,   70,  122,   75,   72,   83,
       70,   76,   73,   72,   70,  129,   78,   74,   72,  306,
       79,  266,   72,   80,  306,   70,   81,   77,   91,   82,

       84,  104,   85,   72,  231,   70,   92,   70,   87,   70,
      181,   93,   86,   72,  127,   72,  126,   72,   88,   70,
      121,   89,   94,  124,   90,  122,   95,   72,   97,   70,
       98,   70,   96,  100,   59,   59,   99,   72,   70,   72,
       70,  101,  105,  102,  107,  103,   70,  108,   72,   70,
       70,  128,  106,   70,   72,  111,  109,   72,   72,  116,
      110,   72,  112,  306,   70,  130,   70,   70,   70,  113,
       70,  114,   72,  115,   72,   72,   72,  131,   72,  127,
      117,   70,  132,  133,   70,   70,   70,  118,   70,   72,
      134,   70,   72,   72,   72,   70,   72,   70,  140,   72,

      126,  124,  142,   72,   69,   72,   66,  135,   70,  137,
      138,  143,  141,  136,  147,   70,   72,  139,  144,   70,
      146,   70,  145,   72,   70,   70,   70,   72,   70,   72,
       62,   61,   72,   72,   72,  306,   72,   58,  152,   70,
       70,   70,   58,  148,  150,  149,  151,   72,   72,   72,
       70,   56,  157,  153,  154,   70,   56,   70,   72,  156,
       70,  155,  159,   72,  158,   72,   70,   70,   72,   54,
       70,   70,   54,   70,   72,   72,   70,  161,   72,   72,
      162,   72,  163,  160,   72,   70,  306,   70,  306,   70,
      306,   70,   70,   72,  164,   72,  166,   72,  169,   72,

       72,  165,  171,   70,   70,  167,  306,  170,  306,   70,
       70,   72,   72,  168,  172,   70,  173,   72,   72,   70,
       70,   70,  176,   72,  306,  174,  175,   72,   72,   72,
       70,   70,  178,   70,   70,  177,  179,   70,   72,   72,
      306,   72,   72,   70,   70,   72,  180,   70,  183,   70,
      184,   72,   72,   70,  306,   72,  306,   72,  189,   70,
      185,   72,  191,  306,  186,  188,   70,   72,   70,   70,
      187,  190,  306,  306,   72,   70,   72,   72,  306,  195,
      196,   70,   70,   72,   70,  192,  193,  306,  194,   72,
       72,   70,   72,   70,  197,  200,   70,   70,  198,   72,

       70,   72,  306,   70,   72,   72,  306,  202,   72,   70,
      199,   72,  306,  203,  201,   70,  204,   72,   70,   70,
      206,   70,   70,   72,  207,   70,   72,   72,  208,   72,
       72,  205,   70,   72,  211,  306,  212,  209,   70,   70,
       72,   70,  306,  210,   70,  213,   72,   72,   70,   72,
      216,  215,   72,  306,  214,   70,   72,   70,   70,   70,
       70,  219,  306,   72,  218,   72,   72,   72,   72,   70,
      217,   70,  306,  306,   70,  306,   70,   72,  306,   72,
      222,  224,   72,  220,   72,  226,  221,   70,   70,   70,
       70,  223,   70,   70,   70,   72,   72,   72,   72,  225,

       72,   72,   72,  306,  306,   70,  306,  306,  306,  229,
      306,  230,  232,   72,  228,  233,  227,   70,  234,   70,
       70,  306,   70,   70,   70,   72,   70,   72,   72,  237,
       72,   72,   72,   70,   72,   70,  236,  240,   70,   70,
       70,   72,  242,   72,   70,  235,   72,   72,   72,  241,
      238,  239,   72,   70,  244,  306,   70,   70,   70,   70,
       70,   72,   70,  243,   72,   72,   72,   72,   72,  245,
       72,   70,   70,   70,   70,   70,  306,  306,  306,   72,
       72,   72,   72,   72,   70,  246,  248,   70,  249,   70,
      247,  306,   72,   70,   70,   72,   70,   72,   70,  250,

      306,   72,   72,   70,   72,   70,   72,  251,  255,  253,
      306,   72,  306,   72,  256,   70,   70,   70,  257,  252,
      254,  306,   70,   72,   72,   72,   70,   70,   70,  259,
       72,  306,  306,   70,   72,   72,   72,   70,  306,  260,
      263,   72,  306,  258,   70,   72,  264,  306,  306,   70,
      265,   70,   72,   70,   70,  261,  262,   72,   70,   72,
       70,   72,   72,   70,   70,   70,   72,  268,   72,  306,
       70,   72,   72,   72,   70,   70,   70,  271,   72,  267,
      306,  306,   72,   72,   72,   70,  269,  272,  270,  275,
       70,   70,  306,   72,   70,   70,  273,   70,   72,   72,

      274,   70,   72,   72,   70,   72,   70,  276,   70,   72,
      306,   70,   72,  278,   72,   70,   72,  282,  280,   72,
       70,   70,  277,   72,   70,  306,   70,   70,   72,   72,
      279,   70,   72,  281,   72,   72,  306,   70,   70,   72,
      286,   70,   70,  283,  287,   72,   72,  284,  285,   72,
       72,   70,   70,   70,   70,   70,  306,   70,   70,   72,
       72,   72,   72,   72,  288,   72,   72,   70,   70,  306,
       70,  291,   70,   70,   70,   72,   72,  289,   72,   70,
       72,   72,   72,  290,   70,   70,   70,   72,  306,   70,
      306,  292,   72,   72,   72,  293,  295,   72,  296,   70,

       70,   70,   70,  294,   70,   70,   70,   72,   72,   72,
       72,   70,   72,   72,   72,  297,   70,   70,   70,   72,
      306,   70,   70,  299,   72,   72,   72,   70,  298,   72,
       72,   70,   70,  303,  306,   72,  301,  306,   70,   72,
       72,   70,  300,   70,  302,  304,   72,   70,  306,   72,
      306,   72,  306,  306,  306,   72,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      306,  305,   53,   53,   53,   53,   53,   53,   53,   53,
       53,   55,   55,   55,   55,   55,   55,   55,   55,   55,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   60,

      306,   60,   65,   65,   65,   71,   71,  306,   71,  119,
      119,  119,  119,  306,  119,  119,  119,  119,  120,  120,
      120,  120,  120,  120,  120,  120,  120,  123,  123,  123,
      306,  123,  123,  123,  123,  123,  125,  306,  125,  125,
      125,  125,  125,  125,  125,  129,  306,  306,  306,  306,
      306,  129,   72,   72,  306,   72,  182,  306,  182,    9,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,

      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  306
    } ;

static const flex_int16_t yy_chk[1016] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,   11,   11,   12,   12,   25,
       32,   25,   28,   28,   33,   38,   35,   64,   32,   64,
       34,   54,   33,   38,   35,   44,   54,   33,   34,   35,
       36,   33,   32,   44,   39,  266,   34,   32,   36,  120,
       34,  231,   39,   34,  120,   37,   34,   33,   39,   34,

       36,   44,   36,   37,  181,   41,   39,   42,   37,   40,
      128,   39,   36,   41,  127,   42,  126,   40,   37,   43,
      121,   37,   40,  124,   37,  121,   40,   43,   41,   45,
       42,   46,   40,   43,   59,   59,   42,   45,   72,   46,
       71,   43,   45,   43,   46,   43,   47,   46,   71,   48,
       49,   70,   45,   73,   47,   47,   46,   48,   49,   49,
       46,   73,   47,   65,   50,   73,   74,   75,   76,   47,
       77,   48,   50,   48,   74,   75,   76,   74,   77,   63,
       50,   78,   75,   76,   79,   81,   82,   50,   80,   78,
       78,   83,   79,   81,   82,   84,   80,   86,   81,   83,

       58,   56,   83,   84,   30,   86,   26,   79,   85,   80,
       80,   83,   82,   79,   86,   87,   85,   80,   83,   88,
       85,   89,   84,   87,   90,   91,   92,   88,   93,   89,
       24,   23,   90,   91,   92,    9,   93,    8,   92,   94,
       95,   96,    7,   87,   89,   88,   90,   94,   95,   96,
       97,    6,   96,   92,   92,   98,    5,   99,   97,   95,
      100,   94,   97,   98,   96,   99,  101,  102,  100,    4,
      103,  104,    3,  105,  101,  102,  106,   99,  103,  104,
      102,  105,  103,   98,  106,  107,    0,  109,    0,  108,
        0,  113,  110,  107,  104,  109,  106,  108,  108,  113,

      110,  105,  110,  112,  111,  107,    0,  109,    0,  114,
      115,  112,  111,  107,  111,  116,  112,  114,  115,  117,
      118,  130,  115,  116,    0,  113,  114,  117,  118,  130,
      131,  132,  117,  133,  134,  116,  117,  135,  131,  132,
        0,  133,  134,  136,  137,  135,  118,  138,  132,  139,
      133,  136,  137,  140,    0,  138,    0,  139,  138,  141,
      134,  140,  140,    0,  135,  137,  143,  141,  142,  144,
      136,  139,    0,    0,  143,  146,  142,  144,    0,  143,
      144,  145,  147,  146,  148,  141,  141,    0,  142,  145,
      147,  149,  148,  150,  145,  148,  151,  154,  145,  149,

      152,  150,    0,  153,  151,  154,    0,  151,  152,  155,
      147,  153,    0,  152,  150,  156,  153,  155,  157,  158,
      154,  159,  160,  156,  155,  161,  157,  158,  156,  159,
      160,  153,  162,  161,  159,    0,  160,  157,  163,  164,
      162,  165,    0,  158,  166,  161,  163,  164,  167,  165,
      164,  163,  166,    0,  162,  168,  167,  169,  170,  171,
      172,  167,    0,  168,  166,  169,  170,  171,  172,  173,
      165,  174,    0,    0,  175,    0,  176,  173,    0,  174,
      172,  174,  175,  169,  176,  176,  171,  177,  178,  179,
      183,  173,  180,  184,  185,  177,  178,  179,  183,  175,

      180,  184,  185,    0,    0,  186,    0,    0,    0,  179,
        0,  180,  183,  186,  178,  184,  177,  187,  186,  188,
      189,    0,  190,  191,  192,  187,  193,  188,  189,  189,
      190,  191,  192,  194,  193,  195,  188,  192,  196,  197,
      198,  194,  194,  195,  199,  187,  196,  197,  198,  193,
      190,  191,  199,  200,  198,    0,  201,  202,  203,  206,
      204,  200,  205,  195,  201,  202,  203,  206,  204,  200,
      205,  207,  208,  209,  210,  211,    0,    0,    0,  207,
      208,  209,  210,  211,  212,  202,  204,  213,  205,  214,
      203,    0,  212,  215,  217,  213,  216,  214,  218,  207,

        0,  215,  217,  219,  216,  220,  218,  212,  218,  216,
        0,  219,    0,  220,  219,  221,  222,  223,  220,  215,
      217,    0,  224,  221,  222,  223,  225,  227,  226,  222,
      224,    0,    0,  228,  225,  227,  226,  229,    0,  224,
      227,  228,    0,  221,  230,  229,  228,    0,    0,  232,
      229,  233,  230,  234,  235,  225,  226,  232,  236,  233,
      237,  234,  235,  238,  239,  240,  236,  235,  237,    0,
      241,  238,  239,  240,  242,  244,  243,  239,  241,  233,
        0,    0,  242,  244,  243,  245,  236,  240,  237,  243,
      246,  247,    0,  245,  248,  249,  241,  250,  246,  247,

      242,  251,  248,  249,  252,  250,  253,  246,  255,  251,
        0,  254,  252,  250,  253,  256,  255,  255,  253,  254,
      257,  258,  248,  256,  259,    0,  260,  261,  257,  258,
      251,  262,  259,  254,  260,  261,    0,  263,  264,  262,
      261,  265,  267,  256,  262,  263,  264,  258,  260,  265,
      267,  268,  269,  270,  271,  272,    0,  273,  274,  268,
      269,  270,  271,  272,  263,  273,  274,  275,  276,    0,
      277,  274,  278,  279,  280,  275,  276,  268,  277,  281,
      278,  279,  280,  272,  283,  282,  284,  281,    0,  285,
        0,  276,  283,  282,  284,  279,  282,  285,  285,  286,

      287,  288,  289,  280,  290,  291,  292,  286,  287,  288,
      289,  293,  290,  291,  292,  289,  294,  295,  296,  293,
        0,  297,  298,  293,  294,  295,  296,  299,  292,  297,
      298,  301,  300,  297,    0,  299,  295,    0,  302,  301,
      300,  303,  294,  304,  296,  300,  302,  305,    0,  303,
        0,  304,    0,    0,    0,  305,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  302,  307,  307,  307,  307,  307,  307,  307,  307,
      307,  308,  308,  308,  308,  308,  308,  308,  308,  308,
      309,  309,  309,  309,  309,  309,  309,  309,  309,  310,

        0,  310,  311,  311,  311,  312,  312,    0,  312,  313,
      313,  313,  313,    0,  313,  313,  313,  313,  314,  314,
      314,  314,  314,  314,  314,  314,  314,  315,  315,  315,
        0,  315,  315,  315,  315,  315,  316,    0,  316,  316,
      316,  316,  316,  316,  316,  317,    0,    0,    0,    0,
        0,  317,  318,  318,    0,  318,  319,    0,  319,  306,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,

      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  306
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;


static int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
static char *yytext;
#line 1 "pars0lex.l"
/*****************************************************************************

Copyright (c) 1997, 2014, Oracle and/or its affiliates. All Rights Reserved.
Copyright (c) 2017, 2019, MariaDB Corporation.

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; version 2 of the License.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1335 USA

*****************************************************************************/
/******************************************************
SQL parser lexical analyzer: input file for the GNU Flex lexer generator

The InnoDB parser is frozen because MySQL takes care of SQL parsing.
Therefore we normally keep the InnoDB parser C files as they are, and do
not automatically generate them from pars0grm.y and pars0lex.l.

How to make the InnoDB parser and lexer C files:

1. Run ./make_flex.sh to generate lexer files.

2. Run ./make_bison.sh to generate parser files.

These instructions seem to work at least with bison-1.875d and flex-2.5.31 on
Linux.

Created 12/14/1997 Heikki Tuuri
*******************************************************/
#define YY_NO_INPUT 1
#define YY_NO_UNISTD_H 1
#line 54 "pars0lex.l"
#define YYSTYPE que_node_t*

#include "univ.i"
#include "pars0pars.h"
#include "pars0grm.h"
#include "pars0sym.h"
#include "mem0mem.h"
#include "os0proc.h"

#define malloc(A)	ut_malloc_nokey(A)
#define free(A)		ut_free(A)
#define realloc(P, A)	ut_realloc(P, A)
#define exit(A) 	ut_error

#define YY_INPUT(buf, result, max_size) \
	result = pars_get_lex_chars(buf, max_size)

/* String buffer for removing quotes */
static ulint	stringbuf_len_alloc = 0; /* Allocated length */
static ulint	stringbuf_len = 0; /* Current length */
static char*	stringbuf; /* Start of buffer */
/** Appends a string to the buffer. */
static
void
string_append(
/*==========*/
	const char*	str,	/*!< in: string to be appended */
	ulint		len)	/*!< in: length of the string */
{
	if (stringbuf == NULL) {
		stringbuf = static_cast<char*>(malloc(1));
		stringbuf_len_alloc = 1;
	}

	if (stringbuf_len + len > stringbuf_len_alloc) {
		while (stringbuf_len + len > stringbuf_len_alloc) {
			stringbuf_len_alloc <<= 1;
		}

		stringbuf = static_cast<char*>(
			realloc(stringbuf, stringbuf_len_alloc));
	}

	memcpy(stringbuf + stringbuf_len, str, len);
	stringbuf_len += len;
}

#line 859 "lexyy.cc"

#line 861 "lexyy.cc"

#define INITIAL 0
#define comment 1
#define quoted 2
#define id 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

MY_ATTRIBUTE((unused)) static int yylex_destroy ( void );

MY_ATTRIBUTE((unused)) static int yyget_debug ( void );

MY_ATTRIBUTE((unused)) static void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );



MY_ATTRIBUTE((unused)) static FILE *yyget_in ( void );

MY_ATTRIBUTE((unused)) static void yyset_in  ( FILE * _in_str  );

MY_ATTRIBUTE((unused)) static FILE *yyget_out ( void );

MY_ATTRIBUTE((unused)) static void yyset_out  ( FILE * _out_str  );

			MY_ATTRIBUTE((unused)) static int yyget_leng ( void );

MY_ATTRIBUTE((unused)) static char *yyget_text ( void );

MY_ATTRIBUTE((unused)) static int yyget_lineno ( void );

MY_ATTRIBUTE((unused)) static void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 112 "pars0lex.l"


#line 1082 "lexyy.cc"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 307 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 306 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 114 "pars0lex.l"
{
			yylval = sym_tab_add_int_lit(pars_sym_tab_global,
								atoi(yytext));
			return(PARS_INT_LIT);
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 120 "pars0lex.l"
{
			ut_error;	/* not implemented */

			return(PARS_FLOAT_LIT);
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 126 "pars0lex.l"
{
			ulint	type;

			yylval = sym_tab_add_bound_lit(pars_sym_tab_global,
				yytext + 1, &type);

			return((int) type);
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 135 "pars0lex.l"
{
			yylval = sym_tab_add_bound_id(pars_sym_tab_global,
				yytext + 1);

			return(PARS_ID_TOKEN);
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 142 "pars0lex.l"
{
/* Quoted character string literals are handled in an explicit
start state 'quoted'.  This state is entered and the buffer for
the scanned string is emptied upon encountering a starting quote.

In the state 'quoted', only two actions are possible (defined below). */
			BEGIN(quoted);
			stringbuf_len = 0;
}
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 151 "pars0lex.l"
{
			/* Got a sequence of characters other than "'":
			append to string buffer */
			string_append(yytext, yyleng);
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 156 "pars0lex.l"
{
			/* Got a sequence of "'" characters:
			append half of them to string buffer,
			as "''" represents a single "'".
			We apply truncating division,
			so that "'''" will result in "'". */

			string_append(yytext, yyleng / 2);

			/* If we got an odd number of quotes, then the
			last quote we got is the terminating quote.
			At the end of the string, we return to the
			initial start state and report the scanned
			string literal. */

			if (yyleng % 2) {
				BEGIN(INITIAL);
				yylval = sym_tab_add_str_lit(
					pars_sym_tab_global,
					(byte*) stringbuf, stringbuf_len);
				return(PARS_STR_LIT);
			}
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 180 "pars0lex.l"
{
/* Quoted identifiers are handled in an explicit start state 'id'.
This state is entered and the buffer for the scanned string is emptied
upon encountering a starting quote.

In the state 'id', only two actions are possible (defined below). */
			BEGIN(id);
			stringbuf_len = 0;
}
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 189 "pars0lex.l"
{
			/* Got a sequence of characters other than '"':
			append to string buffer */
			string_append(yytext, yyleng);
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 194 "pars0lex.l"
{
			/* Got a sequence of '"' characters:
			append half of them to string buffer,
			as '""' represents a single '"'.
			We apply truncating division,
			so that '"""' will result in '"'. */

			string_append(yytext, yyleng / 2);

			/* If we got an odd number of quotes, then the
			last quote we got is the terminating quote.
			At the end of the string, we return to the
			initial start state and report the scanned
			identifier. */

			if (yyleng % 2) {
				BEGIN(INITIAL);
				yylval = sym_tab_add_id(
					pars_sym_tab_global,
					(byte*) stringbuf, stringbuf_len);

				return(PARS_ID_TOKEN);
			}
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 219 "pars0lex.l"
{
			yylval = sym_tab_add_null_lit(pars_sym_tab_global);

			return(PARS_NULL_LIT);
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 225 "pars0lex.l"
{
			/* Implicit cursor name */
			yylval = sym_tab_add_str_lit(pars_sym_tab_global,
							(byte*) yytext, yyleng);
			return(PARS_SQL_TOKEN);
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 232 "pars0lex.l"
{
			return(PARS_AND_TOKEN);
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 236 "pars0lex.l"
{
			return(PARS_OR_TOKEN);
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 240 "pars0lex.l"
{
			return(PARS_NOT_TOKEN);
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 244 "pars0lex.l"
{
			return(PARS_PROCEDURE_TOKEN);
}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 248 "pars0lex.l"
{
			return(PARS_IN_TOKEN);
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 252 "pars0lex.l"
{
			return(PARS_INT_TOKEN);
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 256 "pars0lex.l"
{
			return(PARS_CHAR_TOKEN);
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 260 "pars0lex.l"
{
			return(PARS_IS_TOKEN);
}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 264 "pars0lex.l"
{
			return(PARS_BEGIN_TOKEN);
}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 268 "pars0lex.l"
{
			return(PARS_END_TOKEN);
}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 272 "pars0lex.l"
{
			return(PARS_IF_TOKEN);
}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 276 "pars0lex.l"
{
			return(PARS_THEN_TOKEN);
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 280 "pars0lex.l"
{
			return(PARS_ELSE_TOKEN);
}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 284 "pars0lex.l"
{
			return(PARS_ELSIF_TOKEN);
}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 288 "pars0lex.l"
{
			return(PARS_LOOP_TOKEN);
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 292 "pars0lex.l"
{
			return(PARS_WHILE_TOKEN);
}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 296 "pars0lex.l"
{
			return(PARS_RETURN_TOKEN);
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 300 "pars0lex.l"
{
			return(PARS_SELECT_TOKEN);
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 304 "pars0lex.l"
{
			return(PARS_COUNT_TOKEN);
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 308 "pars0lex.l"
{
			return(PARS_FROM_TOKEN);
}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 312 "pars0lex.l"
{
			return(PARS_WHERE_TOKEN);
}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 316 "pars0lex.l"
{
			return(PARS_FOR_TOKEN);
}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 320 "pars0lex.l"
{
			return(PARS_ORDER_TOKEN);
}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 324 "pars0lex.l"
{
			return(PARS_BY_TOKEN);
}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 328 "pars0lex.l"
{
			return(PARS_ASC_TOKEN);
}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 332 "pars0lex.l"
{
			return(PARS_DESC_TOKEN);
}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 336 "pars0lex.l"
{
			return(PARS_INSERT_TOKEN);
}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 340 "pars0lex.l"
{
			return(PARS_INTO_TOKEN);
}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 344 "pars0lex.l"
{
			return(PARS_VALUES_TOKEN);
}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 348 "pars0lex.l"
{
			return(PARS_UPDATE_TOKEN);
}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 352 "pars0lex.l"
{
			return(PARS_SET_TOKEN);
}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 356 "pars0lex.l"
{
			return(PARS_DELETE_TOKEN);
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 360 "pars0lex.l"
{
			return(PARS_CURRENT_TOKEN);
}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 364 "pars0lex.l"
{
			return(PARS_OF_TOKEN);
}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 368 "pars0lex.l"
{
			return(PARS_CREATE_TOKEN);
}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 372 "pars0lex.l"
{
			return(PARS_TABLE_TOKEN);
}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 376 "pars0lex.l"
{
			return(PARS_INDEX_TOKEN);
}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 380 "pars0lex.l"
{
			return(PARS_UNIQUE_TOKEN);
}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 384 "pars0lex.l"
{
			return(PARS_CLUSTERED_TOKEN);
}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 388 "pars0lex.l"
{
			return(PARS_ON_TOKEN);
}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 392 "pars0lex.l"
{
			return(PARS_DECLARE_TOKEN);
}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 396 "pars0lex.l"
{
			return(PARS_CURSOR_TOKEN);
}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 400 "pars0lex.l"
{
			return(PARS_OPEN_TOKEN);
}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 404 "pars0lex.l"
{
			return(PARS_FETCH_TOKEN);
}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 408 "pars0lex.l"
{
			return(PARS_CLOSE_TOKEN);
}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 412 "pars0lex.l"
{
			return(PARS_NOTFOUND_TOKEN);
}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 416 "pars0lex.l"
{
			return(PARS_TO_BINARY_TOKEN);
}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 420 "pars0lex.l"
{
			return(PARS_SUBSTR_TOKEN);
}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 424 "pars0lex.l"
{
			return(PARS_CONCAT_TOKEN);
}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 428 "pars0lex.l"
{
			return(PARS_INSTR_TOKEN);
}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 432 "pars0lex.l"
{
			return(PARS_LENGTH_TOKEN);
}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 436 "pars0lex.l"
{
			return(PARS_COMMIT_TOKEN);
}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 440 "pars0lex.l"
{
			return(PARS_ROLLBACK_TOKEN);
}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 444 "pars0lex.l"
{
			return(PARS_WORK_TOKEN);
}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 448 "pars0lex.l"
{
			return(PARS_EXIT_TOKEN);
}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 452 "pars0lex.l"
{
			return(PARS_FUNCTION_TOKEN);
}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 456 "pars0lex.l"
{
			return(PARS_LOCK_TOKEN);
}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 460 "pars0lex.l"
{
			return(PARS_SHARE_TOKEN);
}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 464 "pars0lex.l"
{
			return(PARS_MODE_TOKEN);
}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 468 "pars0lex.l"
{
                        return(PARS_LIKE_TOKEN);
}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 472 "pars0lex.l"
{
			return(PARS_BIGINT_TOKEN);
}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 476 "pars0lex.l"
{
			yylval = sym_tab_add_id(pars_sym_tab_global,
							(byte*) yytext,
							ut_strlen(yytext));
			return(PARS_ID_TOKEN);
}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 483 "pars0lex.l"
{
			yylval = sym_tab_add_id(pars_sym_tab_global,
							(byte*) yytext,
							ut_strlen(yytext));
			return(PARS_TABLE_NAME_TOKEN);
}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 490 "pars0lex.l"
{
			return(PARS_DDOT_TOKEN);
}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 494 "pars0lex.l"
{
			return(PARS_ASSIGN_TOKEN);
}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 498 "pars0lex.l"
{
			return(PARS_LE_TOKEN);
}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 502 "pars0lex.l"
{
			return(PARS_GE_TOKEN);
}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 506 "pars0lex.l"
{
			return(PARS_NE_TOKEN);
}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 510 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 515 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 520 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 525 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 530 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 535 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 540 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 545 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 550 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 555 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 560 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 565 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 570 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 575 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 580 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 585 "pars0lex.l"
BEGIN(comment); /* eat up comment */
	YY_BREAK
case 97:
/* rule 97 can match eol */
YY_RULE_SETUP
#line 587 "pars0lex.l"

	YY_BREAK
case 98:
/* rule 98 can match eol */
YY_RULE_SETUP
#line 588 "pars0lex.l"

	YY_BREAK
case 99:
YY_RULE_SETUP
#line 589 "pars0lex.l"
BEGIN(INITIAL);
	YY_BREAK
case 100:
/* rule 100 can match eol */
YY_RULE_SETUP
#line 591 "pars0lex.l"
/* eat up whitespace */
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 594 "pars0lex.l"
{
			fprintf(stderr,"Unrecognized character: %02x\n",
				*yytext);

			ut_error;

			return(0);
}
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 603 "pars0lex.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1942 "lexyy.cc"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(comment):
case YY_STATE_EOF(quoted):
case YY_STATE_EOF(id):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 307 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 307 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 306);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    static void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    MY_ATTRIBUTE((unused)) static void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    static YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    static void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    static void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
MY_ATTRIBUTE((unused)) static void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
MY_ATTRIBUTE((unused)) static void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
MY_ATTRIBUTE((unused)) static int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
MY_ATTRIBUTE((unused)) static FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
MY_ATTRIBUTE((unused)) static FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
MY_ATTRIBUTE((unused)) static int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

MY_ATTRIBUTE((unused)) static char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
MY_ATTRIBUTE((unused)) static void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
MY_ATTRIBUTE((unused)) static void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

MY_ATTRIBUTE((unused)) static void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

MY_ATTRIBUTE((unused)) static int yyget_debug  (void)
{
        return yy_flex_debug;
}

MY_ATTRIBUTE((unused)) static void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
MY_ATTRIBUTE((unused)) static int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

static void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

static void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

static void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 603 "pars0lex.l"


/**********************************************************************
Release any resources used by the lexer. */
void
pars_lexer_close(void)
/*==================*/
{
	yylex_destroy();
	free(stringbuf);
	stringbuf = NULL;
	stringbuf_len_alloc = stringbuf_len = 0;
}

